@@ -10,11 +10,10 @@ import urllib2
 
 from django.core.cache import cache
 from django.template import TemplateSyntaxError
-from django.utils.encoding import smart_unicode
 from django.views.debug import ExceptionReporter
 
 from sentry import conf
-from sentry.helpers import construct_checksum, varmap, transform, get_installed_apps, urlread
+from sentry.helpers import construct_checksum, varmap, transform, get_installed_apps, urlread, force_unicode
 
 logger = logging.getLogger('sentry.errors')
 
@@ -25,7 +24,10 @@ class SentryClient(object):
         kwargs.setdefault('level', logging.ERROR)
         kwargs.setdefault('server_name', conf.NAME)
 
-        checksum = construct_checksum(**kwargs)
+        if 'checksum' not in kwargs:
+            checksum = construct_checksum(**kwargs)
+        else:
+            checksum = kwargs['checksum']
 
         if conf.THRASHING_TIMEOUT and conf.THRASHING_LIMIT:
             cache_key = 'sentry:%s:%s' % (kwargs.get('class_name') or '', checksum)
@@ -90,9 +92,19 @@ class SentryClient(object):
         kwargs.update({
             'logger': record.name,
             'level': record.levelno,
-            'message': record.getMessage(),
+            'message': force_unicode(record.msg),
+            'server_name': conf.NAME,
         })
-        if record.exc_info:
+        
+        # construct the checksum with the unparsed message
+        kwargs['checksum'] = construct_checksum(**kwargs)
+        
+        # save the message with included formatting
+        kwargs['message'] = record.getMessage()
+        
+        # If there's no exception being processed, exc_info may be a 3-tuple of None
+        # http://docs.python.org/library/sys.html#sys.exc_info
+        if record.exc_info and all(record.exc_info):
             return self.create_from_exception(record.exc_info, **kwargs)
 
         return self.process(
@@ -115,29 +127,12 @@ class SentryClient(object):
         """
         if not exc_info:
             exc_info = sys.exc_info()
+
         exc_type, exc_value, exc_traceback = exc_info
 
-        def to_unicode(f):
-            if isinstance(f, dict):
-                nf = dict()
-                for k, v in f.iteritems():
-                    nf[str(k)] = to_unicode(v)
-                f = nf
-            elif isinstance(f, (list, tuple)):
-                f = [to_unicode(f) for f in f]
-            else:
-                try:
-                    f = smart_unicode(f)
-                except (UnicodeEncodeError, UnicodeDecodeError):
-                    f = '(Error decoding value)'
-                except Exception: # in some cases we get a different exception
-                    f = smart_unicode(type(f))
-            return f
-
         def shorten(var):
-            if not isinstance(var, basestring):
-                var = to_unicode(var)
-            if len(var) > 200:
+            var = transform(var)
+            if isinstance(var, basestring) and len(var) > 200:
                 var = var[:200] + '...'
             return var
 
@@ -182,7 +177,7 @@ class SentryClient(object):
 
         data = kwargs.pop('data', {}) or {}
         data['__sentry__'] = {
-            'exc': map(to_unicode, [exc_type.__class__.__module__, exc_value.args, frames]),
+            'exc': map(transform, [exc_type.__class__.__module__, exc_value.args, frames]),
         }
 
         if isinstance(exc_value, TemplateSyntaxError) and hasattr(exc_value, 'source'):
@@ -194,7 +189,7 @@ class SentryClient(object):
         
         tb_message = '\n'.join(traceback.format_exception(exc_type, exc_value, exc_traceback))
 
-        kwargs.setdefault('message', to_unicode(exc_value))
+        kwargs.setdefault('message', transform(force_unicode(exc_value)))
 
         return self.process(
             class_name=exc_type.__name__,
