@@ -554,6 +554,43 @@ class SentryTestCase(TestCase):
         
         self.assertEquals(last.view, 'sentry.tests.views.logging_request_exc')
         self.assertEquals(last.data['url'], 'http://testserver' + reverse('sentry-log-request-exc'))
+        
+    def testCreateFromRecordNoneExcInfo(self):
+        # sys.exc_info can return (None, None, None) if no exception is being
+        # handled anywhere on the stack. See:
+        #  http://docs.python.org/library/sys.html#sys.exc_info
+        client = get_client()
+        record = logging.LogRecord(
+            'foo', 
+            logging.INFO, 
+            pathname=None,
+            lineno=None,
+            msg='test',
+            args=(),
+            exc_info=(None, None, None),
+        )
+        message = client.create_from_record(record)
+        self.assertEquals('test', message.message)
+
+    def testGroupFormatting(self):
+        logger = logging.getLogger()
+        
+        self.setUpHandler()
+
+        logger.error('This is a test %s', 'error')
+        self.assertEquals(Message.objects.count(), 1)
+        self.assertEquals(GroupedMessage.objects.count(), 1)
+        last = Message.objects.get()
+        self.assertEquals(last.logger, 'root')
+        self.assertEquals(last.level, logging.ERROR)
+        self.assertEquals(last.message, 'This is a test error')
+
+        logger.error('This is a test %s', 'message')
+        logger.error('This is a test %s', 'foo')
+        
+        self.assertEquals(Message.objects.count(), 3)
+        self.assertEquals(GroupedMessage.objects.count(), 1)
+        
 
 
 class SentryViewsTest(TestCase):
@@ -767,7 +804,7 @@ class SentryMailTest(TestCase):
         out = mail.outbox[0]
 
         self.assertTrue('Traceback (most recent call last):' in out.body)
-        self.assertTrue("COOKIES:{'commenter_name': 'admin'," in out.body, out.body)
+        self.assertTrue("COOKIES:{'commenter_name': u'admin'," in out.body, out.body)
         self.assertEquals(out.subject, 'Error (EXTERNAL IP): /group/1')
 
     def test_mail_on_creation(self):
